from django import forms

from django_powcaptcha.widgets import PowCaptchaChallengeWidget


class PowCaptchaChallengeField(forms.CharField):
    required = True
    widget = PowCaptchaChallengeWidget



from django import forms

from django_powcaptcha.client import validate_captcha, PowCaptchaValidationException
from django_powcaptcha.fields import PowCaptchaChallengeField


class PowCaptchaForm(forms.Form):
    powcaptcha_challenge = PowCaptchaChallengeField()
    powcaptcha_nonce = forms.CharField(widget=forms.HiddenInput(), required=True)

    def clean(self):
        cleaned_data = super().clean()

        challenge = cleaned_data.get('powcaptcha_challenge', '')
        nonce = cleaned_data.get('powcaptcha_nonce', '')

        try:
            validate_captcha(challenge, nonce)
        except PowCaptchaValidationException:
            raise forms.ValidationError('Failed to validate captcha')

        return cleaned_data



from django.conf import settings
from django.forms import widgets

from django_powcaptcha.client import get_challenge


class PowCaptchaChallengeWidget(widgets.Widget):
    input_type = 'hidden'
    template_name = 'django_powcaptcha/widget.html'

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)
        context.update(
            {
                'captcha_url': settings.POWCAPTCHA_API_URL,
                'captcha_challenge': get_challenge(),
                'captcha_callback': 'myCaptchaCallback',
            }
        )
        return context
